import java.awt.*;
import java.awt.image.*;
import javax.swing.*;

import app.*;
import visual.*;
import io.ResourceFinder;
import visual.dynamic.*;
import visual.dynamic.described.*;
import visual.dynamic.sampled.*;
import visual.statik.*;
import visual.statik.described.*;
import visual.statik.sampled.*;

/**
 * An example that illustrates the use of multiple views
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 *
 */
public class   DualScreenPIPApp
       extends AbstractMultimediaApp
{
    /**
     * The entry point
     */
    public void init()
    {
       Bee                                   bee;       
       visual.statik.sampled.Content         content;       
       ContentFactory                        factory;       
       JPanel                                contentPane;
       ResourceFinder                        finder;       
       Screen                                screen1, screen2;
       SimpleContent[]                       frames1, frames2;
       String                                arg;       
       String[]                              names;       
       VisualizationView                     view1, view2;

       finder = ResourceFinder.createInstance(this);
       
       screen1 = new Screen(4);
       screen1.setRepeating(true);
       
       view1 = screen1.getView();       
       view1.setRenderer(new ScaledVisualizationRenderer(view1.getRenderer(),
                                                         200.0, 200.0));       
       view1.setBounds(200,10,100,100);       
       view1.setSize(100,100);       

       names = finder.loadResourceNames("solidclock.txt");
       factory = new ContentFactory(finder);          

       frames1 = factory.createContents(names, 4);
       for (int i=0; i<frames1.length; i++)
       {
          screen1.add(frames1[i]);          
       }

       screen2 = new Screen();
       screen2.setRepeating(true);
       
       view2 = screen2.getView();       
       view2.setBounds(0,0,320,240);     
       
       names = finder.loadResourceNames("scribble.txt");
       factory = new ContentFactory(finder);          
       frames2 = factory.createContents(names, 4);

       for (int i=0; i<frames2.length; i++)
       {
          screen2.add(frames2[i]);          
       }
       
       // The content pane
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(view1);
       contentPane.add(view2);
       
       screen2.start();
       screen1.start();
    }
}
