import app.*;

import java.util.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * An example of a simple interactive MultimediaApp
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class      InteractiveRandomMessageApp
       extends    AbstractMultimediaApp
       implements ActionListener
{
    // Attributes
    private JLabel                label;       

    // The pseudo-random number generator
    private static Random         rng = new Random();    

    // Action commands
    private static final String   CHANGE = "Change";    

    // The messages
    private static final String[] MESSAGES = {
       "What a great book.","Bring on the exercises.",
       "Author, author!","I hope it never ends."};

    /**
     * Handle actionPerformed() messages
     * (required by ActionListener)
     *
     * @param event  The ActionEvent that generated the message
     */
    public void actionPerformed(ActionEvent event)
    {
       String      actionCommand;
       
       actionCommand = event.getActionCommand();
       if (actionCommand.equals(CHANGE))
       {
          label.setText(createRandomMessage());          
       }
    }

    /**
     * "Create" a message at random
     *
     * @return   The message
     */
    private static String createRandomMessage()
    {
       return  MESSAGES[rng.nextInt(MESSAGES.length)];
    }

    /**
     * Called to indicate that this MultimediaApp has been loaded
     */
    public void init()
    {
       JButton                   button;       
       JPanel                    contentPane;

       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.setLayout(null);
       
       label       = new JLabel(createRandomMessage(), SwingConstants.CENTER);
       label.setBounds(50,50,500,100);       
       contentPane.add(label);    

       button = new JButton(CHANGE);
       button.setBounds(450,300,100,50);
       button.addActionListener(this);       
       contentPane.add(button);
    }
}
