import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;
import javax.swing.*;

import app.*;
import io.*;
import visual.*;
import visual.dynamic.described.*;
import visual.statik.sampled.*;

/**
 * An example of Sprite objects that move together
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public class   BigBusApp
       extends AbstractMultimediaApp
{
    /**
     * The entry point
     */
    public void init()
    {
       BigBus                       bus;
       BufferedImage                image;       
       Content                      content;
       ContentFactory               factory;       
       ImageFactory                 imageFactory;
       int                          height, width;       
       JPanel                       contentPane;       
       ResourceFinder               finder;       
       Stage                        stage;
       VisualizationView            stageView;       


       width  = 640;
       height = 480;       

       finder       = ResourceFinder.createInstance(this);       
       factory      = new ContentFactory(finder);       
       imageFactory = new ImageFactory(finder);

       // The Stage
       stage = new Stage(50);
       stage.setBackground(Color.blue);
       content = factory.createContent("street.png", 3, false);
       stage.add(content);
       stageView = stage.getView();
       stageView.setBounds(0,0,width,height);       

       // The BigBus
       content = factory.createContent("bigbus.png", 4, false);
       bus = new BigBus(content, width, height, stage);
       stage.add(bus);

       // The streetligts in the foreground
       image   = imageFactory.createBufferedImage("streetlight.png", 4);
       content = factory.createContent(image, false);
       content.setLocation(60, 270);       
       stage.add(content);
       content = factory.createContent(image, false);
       content.setLocation(370, 270);       
       stage.add(content);
       
       // The content pane
       contentPane = (JPanel)rootPaneContainer.getContentPane();
       contentPane.add(stageView);

       stage.start();
    }
}
