package visual.statik;

import java.awt.*;
import java.awt.geom.*;

/**
 * The requirements of transformable static visual content
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 */
public interface TransformableContent extends SimpleContent
{
    /**
     * Set the location
     *
     * @param x   The x position
     * @param y   The y position
     */
    public abstract void setLocation(double x, double y);

    /**
     * Set the angle of rotation
     *
     * @param angle   The rotation angle
     * @param x       The x-coordinate of the point to rotate around
     * @param y       The y-coordinate of the point to rotate around
     */
    public abstract void setRotation(double angle, 
                                     double x, double y);

    /**
     * Set the scaling
     *
     * @param xScale   The scaling in the horizontal dimension
     * @param yScale   The scaling in the vertical  dimension
     */
    public abstract void setScale(double xScale, double yScale);

    /**
     * Returns a high precision bounding box of the Content
     * either before or after it is transformed
     *
     * @param    ofTransformed    true to get the BB of the transformed content
     * @return   The bounding box
     */
    public abstract Rectangle2D getBounds2D(boolean ofTransformed);    
}
